PhoneNumberType enum

Type of phone numbers.

Inheritance
Available extensions

Values

FIXED_LINE → const PhoneNumberType
MOBILE → const PhoneNumberType
FIXED_LINE_OR_MOBILE → const PhoneNumberType
TOLL_FREE → const PhoneNumberType
PREMIUM_RATE → const PhoneNumberType
SHARED_COST → const PhoneNumberType
VOIP → const PhoneNumberType
PERSONAL_NUMBER → const PhoneNumberType
PAGER → const PhoneNumberType
UAN → const PhoneNumberType
VOICEMAIL → const PhoneNumberType
UNKNOWN → const PhoneNumberType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int

Available on PhoneNumberType, provided by the phonenumbertypeproperties extension

Returns the index int of the current PhoneNumberType
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PhoneNumberType>
A constant List of the values in this enum, in order of their declaration.